#
# spec file for package opencc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           opencc
Version:        1.0.5
Release:        lp152.5.8
Summary:        Open Chinese Convert
License:        Apache-2.0
Group:          System/I18n/Chinese
Url:            https://github.com/BYVoid/OpenCC
Source:         https://github.com/BYVoid/OpenCC/archive/ver.1.0.5/OpenCC-ver.1.0.5.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
# needed to generate some docu files
BuildRequires:  python3-base

%description
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

%package -n libopencc2
Summary:        Open Chinese Convert
Group:          System/Libraries
Requires:       %{name}-data

%description -n libopencc2
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

This package provides shared libraries of OpenCC.

%package data
Summary:        Dictionaries for Open Chinese Convert
Group:          System/I18n/Chinese

%description data
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

This package provides dictionaries and patterns used by libraries/
binaries of OpenCC.

%package devel
Summary:        Open Chinese Convert
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
OpenCC is an opensource project for conversion between Traditional
Chinese and Simplified Chinese, which supports phrase-level conversion
and regional idioms among Mainland China, Taiwan and Hong kong.

This package provides development headers for OpenCC.

%prep
%setup -q -n OpenCC-ver.%{version}
# call python3 with path
sed -i \
    -e 's:BIN python:BIN /usr/bin/python3:g' \
    data/CMakeLists.txt

%build
%cmake \
  -DCMAKE_SKIP_RPATH=OFF
%make_jobs

%install
%cmake_install
find %{buildroot} -name "*.a" -delete -print

%post -n libopencc2 -p /sbin/ldconfig
%postun -n libopencc2 -p /sbin/ldconfig

%files
%doc AUTHORS NEWS.md LICENSE README.md
%{_bindir}/%{name}
%{_bindir}/%{name}_dict
%{_bindir}/%{name}_phrase_extract

%files data
%{_datadir}/%{name}/

%files -n libopencc2
%{_libdir}/libopencc.so.2
%{_libdir}/libopencc.so.1.0.0

%files devel
%{_includedir}/%{name}/
%{_libdir}/libopencc.so
%{_libdir}/pkgconfig/opencc.pc

%changelog
* Wed Jan  3 2018 tchvatal@suse.com
- Use python3 for all the operations do not implicitely inherit py2
* Thu Nov  2 2017 mpluskal@suse.com
- Cleanup spec file a bit
- Use more of cmake macros
* Thu Oct  5 2017 hillwood@opensuse.org
- Update to 1.0.5
  * Fix link error for mingw
  * Try fix error nodejs_version=4; Platform: x86
  * Add support for node stable && remove v0.12
  * Update artifacts
  * Artifacts for appveyor
* Sat Mar 12 2016 i@marguerite.su
- update version 1.0.3.1
* Wed Aug 12 2015 i@marguerite.su
- update version 1.0.3
* Sun Feb 15 2015 hillwood@linuxfans.org
- Update to 1.0.2
  * Update dictionary
  * Fix scripts compatibility for Python3
  * Fix compatibility with Python3
  * Add non-allocation interface
  * Add Values() to DictEntry for convinience
  * Fix `OPENCC_DEFAULT_CONFIG_SIMP_TO_TRAD`
* Tue Jul  2 2013 i@marguerite.su
- update version 0.4.3
  * add interface: `opencc_convert_utf8_free`
  * fix memeory leak problem for nodejs plugin
* Mon Nov  5 2012 i@marguerite.su
- split a data package to be required by library.
  fix a conversion crash bug in fcitx.
* Sun Jun 24 2012 i@marguerite.su
- fix fedora builds.
* Sun Jun  3 2012 i@marguerite.su
- fix sles builds.
* Thu Feb 16 2012 coolo@suse.com
- trigger the service so it's true
* Mon Jan 23 2012 i@marguerite.su
- initial package 0.3.0
